{ config
, pkgs
, inputs
, lib
, ...
}: {
  programs.mangohud = {
    enable = true;
    settings = {
      # need to override the stylix font size here
      font_size = lib.mkForce 32;
      font_size_text = lib.mkForce 32;
      font_scale = lib.mkForce 1;

      position = "bottom-left";
      horizontal_stretch = 0;
      hud_no_margin = 1;
      hud_compact = 1;
      horizontal = 1;
      cpu_mhz = 1;
      gpu_core_clock = 1;
      ram = 1;
      swap = 1;
      frametime = 0;
      frame_timing = 0;
    };
  };

  programs.mpv = {
    enable = true;
    package = pkgs.mpv;
  };
  programs.thunderbird = {
    enable = true;
    package = pkgs.thunderbird-128;
    profiles."main" = {
      isDefault = true;
    };
  };
  programs.nheko = {
    # enable = true; # insecure due to downstream olm
  };
  programs.obs-studio = {
    enable = true;
    plugins = with pkgs.obs-studio-plugins; [
      wlrobs
      obs-backgroundremoval
      obs-pipewire-audio-capture
      obs-vaapi
      obs-gstreamer
    ];
  };

  xdg.desktopEntries = {
    steam-15 = {
      name = "Steam (1.5 Scaling)";
      type = "Application";
      icon = "steam";
      comment = "steam with forced 2x scaling for highdpi displays";
      exec = "steam -forcedesktopscaling 1.5";
      terminal = false;
      prefersNonDefaultGPU = true;
      categories = [ "Network" "FileTransfer" "Game" ];
    };

    steam-2 = {
      name = "Steam (2.0 Scaling)";
      type = "Application";
      icon = "steam";
      comment = "steam with forced 2x scaling for highdpi displays";
      exec = "steam -forcedesktopscaling 2";
      terminal = false;
      prefersNonDefaultGPU = true;
      categories = [ "Network" "FileTransfer" "Game" ];
    };
  };

  qt.enable = true;
  qt.platformTheme.name = "kde6";

  services.syncthing.enable = true;
  # services.syncthing.tray.enable = true;
  home = {
    file."Pictures/default_background.png".source = config.stylix.image;

    packages = with pkgs; [
      stc-cli
      syncthing
      syncthingtray
      # Steam#####
      # steam-tui
      # steamcmd
      ############
      bitwarden
      # airshipper
      # ardour
      brave
      # cavalier
      ffmpeg
      freetube
      # element-desktop
      inkscape
      jellyfin-mpv-shim # broken ?
      jellyfin-media-player
      warp-terminal
      libsForQt5.kasts
      krita
      kdePackages.kate
      kdePackages.kdenlive
      kdePackages.kleopatra
      kdePackages.plasma-vault
      kdePackages.plasma-browser-integration
      kdePackages.kio-admin
      kdePackages.filelight
      nextcloud-client
      onlyoffice-bin
      protonup-qt
      signal-desktop
      # webcord-vencord # broken atm
      # tome4
      # shattered-pixel-dungeon
      gst_all_1.gst-vaapi
      waypipe
      veracrypt
      lutris
      heroic
      # kdePackages.konversation
      unar
      fuse
      qbittorrent
      # pcsx2
      xdelta
      winetricks
      my.zen-browser
      # my.dbeaver
      # feather
      # freecad-wayland
      # dbeaver-bin
      # blender
      # miraclecast
      # rustdesk
      # deadbeef-with-plugins
      # flightgear
      # orbiter
    ];
  };
}
